package com.gxx.record.service.impl;

import javax.jms.Destination;
import javax.jms.JMSException;
import javax.jms.Message;
import javax.jms.Session;

import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jms.core.JmsTemplate;
import org.springframework.jms.core.MessageCreator;
import org.springframework.stereotype.Service;

import com.gxx.record.service.JmsService;

/**
 * <dl>
 *	<dt><b>Title:</b></dt>
 *	<dd>
 *		用户服务实现类
 *	</dd>
 *	<dt><b>Description:</b></dt>
 *	<dd>
 *		<p>none
 *	</dd>
 * </dl>
 *
 * @author Administrator
 * @version 1.0, 2015年6月18日
 * @since record
 *
 */
@Service("jmsService")
public class JmsServiceImpl implements JmsService {

	/**
	 * 日志处理器
	 */
	Logger logger = Logger.getLogger(JmsServiceImpl.class);

	@Autowired
	private JmsTemplate jmsTemplate;
	
	/**
	 * 点对点(Point-to-Point)目的地
	 */
	@Autowired
	Destination queueDestination;
	
	/**
	 * 发布/订阅(Publish/Subscribe)目的地
	 */
	@Autowired
	Destination topicDestination;
	
	@Override
	/**
	 * 想默认目的地发送消息
	 * @param message
	 */
	public void sendMessage(final String message) {
		logger.info("生产者向默认目的地发了一个消息：" + message);
		jmsTemplate.send(queueDestination, new MessageCreator() {
			public Message createMessage(Session session) throws JMSException {
				return session.createTextMessage(message);
			}
		});
	}

	@Override
	/**
	 * 指定目的地发送消息
	 * @param destination
	 * @param message
	 */
	public void sendMessage(final Destination destination, final String message){
		logger.info("生产者向指定目的地发了一个消息：" + message);
		jmsTemplate.send(destination, new MessageCreator() {
			public Message createMessage(Session session) throws JMSException {
				return session.createTextMessage(message);
			}
		});
	}
}