package com.gxx.record.service.impl;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import com.gxx.record.service.RedisService;

/**
 * <dl>
 *    <dt><b>Title:</b></dt>
 *    <dd>
 *    	redis服务实现类
 *    </dd>
 *    <dt><b>Description:</b></dt>
 *    <dd>
 *    	<p>none
 *    </dd>
 * </dl>
 *
 * @author Administrator
 * @version 1.0, 2015年7月19日
 * @since record
 *
 */
@Service("redisService")
public class RedisServiceImpl implements RedisService {
	
	@Autowired
	private RedisTemplate<String, Object> redisTemplate;
	
	/**
	 * set
	 * @param key
	 * @param value
	 * @return
	 */
	public boolean set(String key, Object value) {
		redisTemplate.opsForValue().set(key, value);
		return Boolean.TRUE.booleanValue();
	}
	
	/**
	 * get
	 * @param key
	 * @return
	 */
	public Object get(String key) {
		return redisTemplate.opsForValue().get(key);
	}
	
	/**
	 * delete
	 * @param key
	 * @return
	 */
	public Object delete(String key) {
		Object object = redisTemplate.opsForValue().get(key);
		if( object!=null){
			redisTemplate.delete(key);
		}
		return object;
	}
	
	/**
	 * listLeftPush
	 * @param key
	 * @return
	 */
	public long listLeftPush(String key, String url) {
		long size = redisTemplate.opsForList().leftPush(key, url);
		return size;
	}
	
	/**
	 * listRightPush
	 * @param key
	 * @return
	 */
	public long listRightPush(String key, String url) {
		long size = redisTemplate.opsForList().rightPush(key, url);
		return size;
	}
	
	/**
	 * listRange
	 * @param key
	 * @return
	 */
	public List<Object> listRange(String key, long start, long end) {
		List<Object> list = redisTemplate.opsForList().range(key, start, end);
		return list;
	}
	
	/**
	 * hashSetNx
	 * @param hash
	 * @param key
	 * @param value
	 * @return
	 */
	public boolean hashSetNx(String hash, String key, String value) {
		return redisTemplate.opsForHash().putIfAbsent(hash, key, value);
	}
	
	/**
	 * hashSize
	 * @param hash
	 * @return
	 */
	public long hashSize(String hash) {
		return redisTemplate.opsForHash().size(hash);
	}
	
	/**
	 * hashExist
	 * @param hash
	 * @param key
	 * @return
	 */
	public boolean hashExist(String hash, String key) {
		return redisTemplate.opsForHash().hasKey(hash, key);
	}
}
