package com.gxx.record.web.user;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang3.StringUtils;
import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import com.gxx.record.base.master.vo.User;
import com.gxx.record.dto.UserDto;
import com.gxx.record.service.master.MasterUserService;
import com.gxx.record.service.slave.SlaveUserService;

/**
 * UserController
 * 
 * @author gxx
 */
@Controller
@RequestMapping("/user/")
public class UserController {
	/**
	 * 日志处理器
	 */
	private final Logger logger = Logger.getLogger(UserController.class);
	
	@Autowired
	private MasterUserService masterUserService;
	
	@Autowired
	private SlaveUserService slaveUserService;
	
	@RequestMapping(value = "/preRegistFtl", method = RequestMethod.GET)
	public String preRegistFtl() {
		return "user/preRegistFtl";
	}
	
	@RequestMapping(value = "/preRegistJsp", method = RequestMethod.GET)
	public String preRegistJsp() {
		return "user/preRegistJsp";
	}
	
	/**
	 * 注册
	 * @param request
	 * @param userDto
	 * @return
	 */
	@RequestMapping(value = "/registJsp",produces="application/json")
	public @ResponseBody UserDto registJsp(HttpServletRequest request, UserDto userDto) {
		logger.info("用户注册：主从=[" + userDto.getMasterOrSlave() + "]，姓名=[" + userDto.getName() + "]，密码=[" + userDto.getPassword() + "]");
		/**
		 * 1.判用户名是否存在
		 */
		if(StringUtils.equals(userDto.getMasterOrSlave(), UserDto.MASTER)){
			User user = masterUserService.getUserByName(userDto.getName());
			if(user != null){
				userDto.setSuccess(Boolean.FALSE.booleanValue());
				userDto.setMessage("用户名[" + userDto.getName() + "]已存在!");
				return userDto;
			}
			/**
			 * 2.创建用户对象 并 新增用户
			 */
			user = new User();
			user.setName(userDto.getName());
			user.setPassword(userDto.getPassword());
			user.setCreateDate("20150618");
			user.setCreateTime("000000");
			masterUserService.doSaveUser(user);
			/**
			 * 3.返回结果
			 */
			userDto.setSuccess(Boolean.TRUE.booleanValue());
			userDto.setMessage("注册成功!");
			return userDto;
		} else if(StringUtils.equals(userDto.getMasterOrSlave(), UserDto.SLAVE)){
			com.gxx.record.base.slave.vo.User user = slaveUserService.getUserByName(userDto.getName());
			if(user != null){
				userDto.setSuccess(Boolean.FALSE.booleanValue());
				userDto.setMessage("用户名[" + userDto.getName() + "]已存在!");
				return userDto;
			}
			/**
			 * 2.创建用户对象 并 新增用户
			 */
			user = new com.gxx.record.base.slave.vo.User();
			user.setName(userDto.getName());
			user.setPassword(userDto.getPassword());
			user.setCreateDate("20150618");
			user.setCreateTime("000000");
			slaveUserService.doSaveUser(user);
			/**
			 * 3.返回结果
			 */
			userDto.setSuccess(Boolean.TRUE.booleanValue());
			userDto.setMessage("注册成功!");
			return userDto;
		} else {
			userDto.setSuccess(Boolean.FALSE.booleanValue());
			userDto.setMessage("主还是从值[" + userDto.getMasterOrSlave() + "]有误!");
			return userDto;
		}
	}
	
	/**
	 * 注册
	 * @param request
	 * @param userDto
	 * @return
	 */
	@RequestMapping(value = "/registFtl")
	public String registFtl(HttpServletRequest request, UserDto userDto) {
		logger.info("用户注册：主从=[" + userDto.getMasterOrSlave() + "]，姓名=[" + userDto.getName() + "]，密码=[" + userDto.getPassword() + "]");
		/**
		 * 1.判用户名是否存在
		 */
		if(StringUtils.equals(userDto.getMasterOrSlave(), UserDto.MASTER)){
			User user = masterUserService.getUserByName(userDto.getName());
			if(user != null){
				userDto.setSuccess(Boolean.FALSE.booleanValue());
				userDto.setMessage("用户名[" + userDto.getName() + "]已存在，请更改用户名!");
				return "user/result";
			}
			/**
			 * 2.创建用户对象 并 新增用户
			 */
			user = new User();
			user.setName(userDto.getName());
			user.setPassword(userDto.getPassword());
			user.setCreateDate("20150618");
			user.setCreateTime("000000");
			masterUserService.doSaveUser(user);
			/**
			 * 3.返回结果
			 */
			userDto.setSuccess(Boolean.TRUE.booleanValue());
			userDto.setMessage("注册成功!");
			return "user/result";
		} else if(StringUtils.equals(userDto.getMasterOrSlave(), UserDto.SLAVE)){
			com.gxx.record.base.slave.vo.User user = slaveUserService.getUserByName(userDto.getName());
			if(user != null){
				userDto.setSuccess(Boolean.FALSE.booleanValue());
				userDto.setMessage("用户名[" + userDto.getName() + "]已存在，请更改用户名!");
				return "user/result";
			}
			/**
			 * 2.创建用户对象 并 新增用户
			 */
			user = new com.gxx.record.base.slave.vo.User();
			user.setName(userDto.getName());
			user.setPassword(userDto.getPassword());
			user.setCreateDate("20150618");
			user.setCreateTime("000000");
			slaveUserService.doSaveUser(user);
			/**
			 * 3.返回结果
			 */
			userDto.setSuccess(Boolean.TRUE.booleanValue());
			userDto.setMessage("注册成功!");
			return "user/result";
		} else {
			userDto.setSuccess(Boolean.FALSE.booleanValue());
			userDto.setMessage("主还是从值[" + userDto.getMasterOrSlave() + "]有误!");
			return "user/result";
		}
	}
}